@@ -600,6 +600,26 @@ def artefacts(tmp_path):
             ],
             "fvp-morello-android-multicore.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-morello-android",
+                *FVP_MORELLO_ANDROID,
+                "--tests",
+                "smc91x",
+            ],
+            "fvp-morello-android-smc91x.yaml",
+        ),
+        (
+            [
+                "--device",
+                "fvp-morello-android",
+                *FVP_MORELLO_ANDROID,
+                "--tests",
+                "virtio_net",
+            ],
+            "fvp-morello-android-virtio_net.yaml",
+        ),
         (
             [
                 "--device",
@@ -656,6 +676,29 @@ def artefacts(tmp_path):
             ],
             "fvp-morello-busybox-purecap.yaml",
         ),
+        (
+            [
+                "--device",
+                "fvp-morello-busybox",
+                "--ap-romfw",
+                "tf-bl1.bin",
+                "--mcp-fw",
+                "mcp_fw.bin",
+                "--mcp-romfw",
+                "mcp_romfw.bin",
+                "--rootfs",
+                "busybox.img.xz",
+                "--scp-fw",
+                "scp_fw.bin",
+                "--scp-romfw",
+                "scp_romfw.bin",
+                "--fip",
+                "fip.bin",
+                "--tests",
+                "smc91x",
+            ],
+            "fvp-morello-busybox-smc91x.yaml",
+        ),
         (
             [
                 "--device",
